pub enum BibleLibError {
InvalidCustomTranslationFile,
VerseNotFound,
ChapterNotFound,
BookNotFound,
InvalidVerseFormat,
IOError(Error),
}Expand description
Errors that can occur in the Bible Lib
Variants
InvalidCustomTranslationFile
The specified custom translation file is invalid or does not exist.
VerseNotFound
The specified verse was not found in the translation.
ChapterNotFound
The specified chapter was not found in the translation.
BookNotFound
The specified book was not found in the translation.
InvalidVerseFormat
The verse format provided is invalid.
IOError(Error)
An I/O error occurred.