pub enum Translation {
AmericanKingJames,
AmericanStandard,
EnglishRevised,
KingJames,
Custom {
name: String,
path: String,
},
}Expand description
Different Bible Translations provided by https://openbible.com/
Variants
AmericanKingJames
American King James Version
AmericanStandard
American Standard Version
EnglishRevised
English Revised Version
KingJames
King James Version
Custom
For custom translations,
each line must be a verse formatted as: Book Chapter:Verse Content
See bible_translations/ for examples
name is strictly for display purposes
note: other translations are included in the binary at compile time, but custom translations are read from the filesystem at runtime